==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/LoT/AwsIoTFireTvStick.md <==
# AwsIoTFireTvStick


```text
aws-q2-2022/Resource/LoT/AwsIoTFireTvStick
```

```text
include('aws-q2-2022/Resource/LoT/AwsIoTFireTvStick')
```



| Illustration | AwsIoTFireTvStick | AwsIoTFireTvStickCard | AwsIoTFireTvStickGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/LoT/AwsIoTFireTvStick.png) | ![illustration for AwsIoTFireTvStick](../../../aws-q2-2022/Resource/LoT/AwsIoTFireTvStick.Local.png) | ![illustration for AwsIoTFireTvStickCard](../../../aws-q2-2022/Resource/LoT/AwsIoTFireTvStickCard.Local.png) | ![illustration for AwsIoTFireTvStickGroup](../../../aws-q2-2022/Resource/LoT/AwsIoTFireTvStickGroup.Local.png) |




## AwsIoTFireTvStick

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStick
include('aws-q2-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStick('AwsIoTFireTvStick', 'Aws Io T Fire Tv Stick', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStick
include('aws-q2-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStick('AwsIoTFireTvStick', 'Aws Io T Fire Tv Stick', 'an optional tech label')
@enduml
```

## AwsIoTFireTvStickCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStickCard
include('aws-q2-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStickCard('AwsIoTFireTvStickCard', 'Aws Io T Fire Tv Stick Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStickCard
include('aws-q2-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStickCard('AwsIoTFireTvStickCard', 'Aws Io T Fire Tv Stick Card', 'an optional description')
@enduml
```

## AwsIoTFireTvStickGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStickGroup
include('aws-q2-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStickGroup('AwsIoTFireTvStickGroup', 'Aws Io T Fire Tv Stick Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStickGroup
include('aws-q2-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStickGroup('AwsIoTFireTvStickGroup', 'Aws Io T Fire Tv Stick Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q1-2022/Resource/LoT/AwsIoTFireTvStick.md <==
# AwsIoTFireTvStick


```text
aws-q1-2022/Resource/LoT/AwsIoTFireTvStick
```

```text
include('aws-q1-2022/Resource/LoT/AwsIoTFireTvStick')
```



| Illustration | AwsIoTFireTvStick | AwsIoTFireTvStickCard | AwsIoTFireTvStickGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/LoT/AwsIoTFireTvStick.png) | ![illustration for AwsIoTFireTvStick](../../../aws-q1-2022/Resource/LoT/AwsIoTFireTvStick.Local.png) | ![illustration for AwsIoTFireTvStickCard](../../../aws-q1-2022/Resource/LoT/AwsIoTFireTvStickCard.Local.png) | ![illustration for AwsIoTFireTvStickGroup](../../../aws-q1-2022/Resource/LoT/AwsIoTFireTvStickGroup.Local.png) |




## AwsIoTFireTvStick

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStick
include('aws-q1-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStick('AwsIoTFireTvStick', 'Aws Io T Fire Tv Stick', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStick
include('aws-q1-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStick('AwsIoTFireTvStick', 'Aws Io T Fire Tv Stick', 'an optional tech label', 'an optional description')
@enduml
```

## AwsIoTFireTvStickCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStickCard
include('aws-q1-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStickCard('AwsIoTFireTvStickCard', 'Aws Io T Fire Tv Stick Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStickCard
include('aws-q1-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStickCard('AwsIoTFireTvStickCard', 'Aws Io T Fire Tv Stick Card', 'an optional description')
@enduml
```

## AwsIoTFireTvStickGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStickGroup
include('aws-q1-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStickGroup('AwsIoTFireTvStickGroup', 'Aws Io T Fire Tv Stick Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTFireTvStickGroup
include('aws-q1-2022/Resource/LoT/AwsIoTFireTvStick')

' renders the element
AwsIoTFireTvStickGroup('AwsIoTFireTvStickGroup', 'Aws Io T Fire Tv Stick Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
